"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "block-closing-brace-newline";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected newline before closing \"}\"";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before closing \"}\"";
  },
  expectedAfter: function expectedAfter() {
    return "Expected newline after closing \"}\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after closing \"}\"";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker("\n", spaceOptions, messages);

  return function (css, result) {
    // Check both kinds of "block": rules and at-rules
    css.eachRule(checkBlock);
    css.eachAtRule(checkBlock);

    function checkBlock(block) {
      // For "before" we're really just checking whether a
      // newline *starts* the block's final space --- between
      // the last declaration and the closing brace. We can
      // ignore any other whitespace between them, because that
      // will be checked by the indentation rule.
      if (spaceOptions.expectBefore && block.after[0] !== "\n") {
        result.warn(messages.expectedBefore(), { node: block });
      }
      if (spaceOptions.rejectBefore && block.after) {
        result.warn(messages.rejectedBefore(), { node: block });
      }

      var nextNode = block.next();
      if (!nextNode) {
        return;
      }

      // Only check one after, because there might be other
      // spaces handled by the indentation rule
      spaceChecker.oneAfter(nextNode.toString(), -1, function (msg) {
        result.warn(msg, { node: block });
      });
    }
  };
};