"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "block-closing-brace-space";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected single space before closing \"}\"";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before closing \"}\"";
  },
  expectedAfter: function expectedAfter() {
    return "Expected single space after closing \"}\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after closing \"}\"";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker(" ", spaceOptions, messages);

  return function (css, result) {
    // Check both kinds of "block": rules and at-rules
    css.eachRule(checkBlock);
    css.eachAtRule(checkBlock);

    function checkBlock(block) {
      var blockString = block.toString();

      spaceChecker.before(blockString, blockString.length - 1, function (msg) {
        result.warn(msg, { node: block });
      });

      var nextNode = block.next();
      if (!nextNode) {
        return;
      }
      spaceChecker.after(nextNode.toString(), -1, function (msg) {
        result.warn(msg, { node: block });
      });
    }
  };
};