"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "block-opening-brace-newline";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected newline before opening \"{\"";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before opening \"{\"";
  },
  expectedAfter: function expectedAfter() {
    return "Expected newline after opening \"{\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after opening \"{\"";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker("\n", spaceOptions, messages);

  return function (css, result) {
    // Check both kinds of "block": rules and at-rules
    css.eachRule(checkBlock);
    css.eachAtRule(checkBlock);

    function checkBlock(block) {
      var blockString = block.toString();
      for (var i = 0, l = blockString.length; i < l; i++) {
        if (blockString[i] !== "{") {
          continue;
        }
        // Only pay attention to the first brace encountered
        checkBrace(i);
        break;
      }

      function checkBrace(index) {
        spaceChecker.before(blockString, index, function (msg) {
          result.warn(msg, { node: block });
        });
        spaceChecker.oneAfter(blockString, index, function (msg) {
          result.warn(msg, { node: block });
        });
      }
    }
  };
};