"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testDeclarationBangBefore = _testUtils.ruleTester(_2["default"], _.ruleName);

testDeclarationBangBefore({ before: "always" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink !important; }", "space only before");
  tr.ok("a { color: pink ! important; }", "space before and after");
  tr.ok("a { color: pink !\nimportant; }", "space before and newline after");

  tr.notOk("a { color: pink  !important; }", _.messages.expectedBefore(), "two spaces before");
  tr.notOk("a { color: pink!important; }", _.messages.expectedBefore(), "no space before");
  tr.notOk("a { color: pink\n!important; }", _.messages.expectedBefore(), "newline before");
});

testDeclarationBangBefore({ before: "never" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink!important; }", "no spaces");
  tr.ok("a { color: pink! important; }", "no space before and after");
  tr.ok("a { color: pink!\nimportant; }", "no space before and newline after");

  tr.notOk("a { color: pink !important; }", _.messages.rejectedBefore(), "space before");
  tr.notOk("a { color: pink\n!important; }", _.messages.rejectedBefore(), "newline before");
});

testDeclarationBangBefore({ after: "always" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink! important; }", "space only after");
  tr.ok("a { color: pink ! important; }", "space before and after");
  tr.ok("a { color: pink\n! important; }", "newline before and space after");

  tr.notOk("a { color: pink!important; }", _.messages.expectedAfter(), "no space after");
  tr.notOk("a { color: pink!  important; }", _.messages.expectedAfter(), "two spaces after");
  tr.notOk("a { color: pink!\nimportant; }", _.messages.expectedAfter(), "newline after");
});

testDeclarationBangBefore({ after: "never" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink!important; }", "no space before or after");
  tr.ok("a { color: pink !important; }", "space before and none after");
  tr.ok("a { color: pink\n!important; }", "newline before and none after");

  tr.notOk("a { color: pink! important; }", _.messages.rejectedAfter(), "space after");
  tr.notOk("a { color: pink!\nimportant; }", _.messages.rejectedAfter(), "newline after");
});

testDeclarationBangBefore({ before: "always", after: "never" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink !important; }", "space only before");

  tr.notOk("a { color: pink ! important; }", _.messages.rejectedAfter(), "space before and after");
  tr.notOk("a { color: pink  !important; }", _.messages.expectedBefore(), "two spaces before");
  tr.notOk("a { color: pink!important; }", _.messages.expectedBefore(), "no space before");
  tr.notOk("a { color: pink\n!important; }", _.messages.expectedBefore(), "newline before");
});

testDeclarationBangBefore({ before: "never", after: "always" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink! important; }", "space only after");

  tr.notOk("a { color: pink ! important; }", _.messages.rejectedBefore(), "space before and after");
  tr.notOk("a { color: pink!  important; }", _.messages.expectedAfter(), "two spaces after");
  tr.notOk("a { color: pink!important; }", _.messages.expectedAfter(), "no space after");
  tr.notOk("a { color: pink!\nimportant; }", _.messages.expectedAfter(), "newline before");
});

testDeclarationBangBefore({ before: "always", after: "always" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink ! important; }", "space before and after");

  tr.notOk("a { color: pink! important; }", _.messages.expectedBefore(), "no space before and one after");
  tr.notOk("a { color: pink  ! important; }", _.messages.expectedBefore(), "two spaces before and one after");
  tr.notOk("a { color: pink! important; }", _.messages.expectedBefore(), "no space before and one after");
  tr.notOk("a { color: pink\n! important; }", _.messages.expectedBefore(), "newline before and one after");
  tr.notOk("a { color: pink !important; }", _.messages.expectedAfter(), "one space before and none after");
  tr.notOk("a { color: pink !  important; }", _.messages.expectedAfter(), "one before and two after");
  tr.notOk("a { color: pink !important; }", _.messages.expectedAfter(), "one space before and none after");
  tr.notOk("a { color: pink !\nimportant; }", _.messages.expectedAfter(), "one space before and newline after");
});

testDeclarationBangBefore({ before: "never", after: "never" }, function (tr) {
  tr.ok("a { color: pink; }", "no !important");
  tr.ok("a { color: pink!important; }", "no spaces before or after");

  tr.notOk("a { color: pink! important; }", _.messages.rejectedAfter(), "no space before and one after");
  tr.notOk("a { color: pink !important; }", _.messages.rejectedBefore(), "one space before and none after");
  tr.notOk("a { color: pink\n!important; }", _.messages.rejectedBefore(), "newline before and no space after");
  tr.notOk("a { color: pink!\nimportant; }", _.messages.rejectedAfter(), "no space before and newline after");
});