"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "declaration-bang-space";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected single space before \"!\"";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before \"!\"";
  },
  expectedAfter: function expectedAfter() {
    return "Expected single space after \"!\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after \"!\"";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker(" ", spaceOptions, messages);

  return function (css, result) {
    css.eachDecl(function (decl) {
      if (!decl.important) {
        return;
      }
      var declString = decl.toString();

      // Start from the right and only pay attention to the first
      // exclamation mark found
      for (var i = declString.length - 1; i >= 0; i--) {
        if (declString[i] !== "!") {
          continue;
        }
        checkBang(i);
        break;
      }

      function checkBang(index) {
        spaceChecker.before(declString, index, function (msg) {
          result.warn(msg, { node: decl });
        });
        spaceChecker.after(declString, index, function (msg) {
          result.warn(msg, { node: decl });
        });
      }
    });
  };
};