"use strict";

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _testUtils = require("../../../testUtils");

var _ = require("..");

var _2 = _interopRequireDefault(_);

var testDeclarationColonSpace = _testUtils.ruleTester(_2["default"], _.ruleName);

testDeclarationColonSpace({ "before": "always" }, function (tr) {
  tr.ok("a { color :pink }", "space only before");
  tr.ok("a { color : pink }", "space before and after");
  tr.ok("a { color :\npink }", "space before and newline after");

  tr.notOk("a { color: pink; }", _.messages.expectedBefore(), "no space before");
  tr.notOk("a { color  : pink; }", _.messages.expectedBefore(), "two spaces before");
  tr.notOk("a { color\t: pink; }", _.messages.expectedBefore(), "tab before");
  tr.notOk("a { color\n: pink; }", _.messages.expectedBefore(), "newline before");
});

testDeclarationColonSpace({ "before": "never" }, function (tr) {
  tr.ok("a { color:pink }", "no space before and after");
  tr.ok("a { color: pink }", "no space before and space after");
  tr.ok("a { color:\npink }", "no space before and newline after");

  tr.notOk("a { color : pink; }", _.messages.rejectedBefore(), "space before");
  tr.notOk("a { color  : pink; }", _.messages.rejectedBefore(), "two spaces before");
  tr.notOk("a { color\t: pink; }", _.messages.rejectedBefore(), "tab before");
  tr.notOk("a { color\n: pink; }", _.messages.rejectedBefore(), "newline before");
});

testDeclarationColonSpace({ "after": "always" }, function (tr) {
  tr.ok("a { color: pink }", "space only after");
  tr.ok("a { color : pink }", "space before and after");
  tr.ok("a { color\n: pink }", "newline before and space after");

  tr.notOk("a { color :pink; }", _.messages.expectedAfter(), "no space after");
  tr.notOk("a { color :  pink; }", _.messages.expectedAfter(), "two spaces after");
  tr.notOk("a { color :\tpink; }", _.messages.expectedAfter(), "tab after");
  tr.notOk("a { color :\npink; }", _.messages.expectedAfter(), "newline after");
});

testDeclarationColonSpace({ "after": "never" }, function (tr) {
  tr.ok("a { color:pink }", "no space before and after");
  tr.ok("a { color :pink }", "space before and no space after");
  tr.ok("a { color\n:pink }", "newline before and no space after");

  tr.notOk("a { color : pink; }", _.messages.rejectedAfter(), "space after");
  tr.notOk("a { color:  pink; }", _.messages.rejectedAfter(), "two spaces after");
  tr.notOk("a { color :\tpink; }", _.messages.rejectedAfter(), "tab after");
  tr.notOk("a { color :\npink; }", _.messages.rejectedAfter(), "newline after");
});

testDeclarationColonSpace({ "before": "always", "after": "never" }, function (tr) {
  tr.ok("a { color :pink; }", "space before and none after");

  tr.notOk("a { color : pink }", _.messages.rejectedAfter(), "space before and after");
  tr.notOk("a { color  :pink; }", _.messages.expectedBefore(), "two spaces before");
  tr.notOk("a { color:pink; }", _.messages.expectedBefore(), "no space before");
  tr.notOk("a { color\n:pink; }", _.messages.expectedBefore(), "newline before");
});

testDeclarationColonSpace({ before: "never", after: "always" }, function (tr) {
  tr.ok("a { color: pink }", "space only after");

  tr.notOk("a { color : pink; }", _.messages.rejectedBefore(), "space before and after");
  tr.notOk("a { color:  pink!; }", _.messages.expectedAfter(), "two spaces after");
  tr.notOk("a { color:pink; }", _.messages.expectedAfter(), "no space after");
  tr.notOk("a { color:\npink; }", _.messages.expectedAfter(), "newline after");
});

testDeclarationColonSpace({ "before": "always", "after": "always" }, function (tr) {
  tr.ok("a { color : pink }", "space before and after");

  tr.notOk("a { color: pink; }", _.messages.expectedBefore(), "no space before and one after");
  tr.notOk("a { color  : pink; }", _.messages.expectedBefore(), "two spaces before and on after");
  tr.notOk("a { color\n: pink; }", _.messages.expectedBefore(), "newline before and spaceafter");
  tr.notOk("a { color :pink}", _.messages.expectedAfter(), "one space before and noe after");
  tr.notOk("a { color :  pink }", _.messages.expectedAfter(), "one before and two afte");
  tr.notOk("a { color :pink }", _.messages.expectedAfter(), "one space before and noe after");
  tr.notOk("a { color :\npink }", _.messages.expectedAfter(), "one space before and neline after");
});

testDeclarationColonSpace({ "before": "never", "after": "never" }, function (tr) {
  tr.ok("a { color:pink; }", "no spaces before or after");

  tr.notOk("a { color: pink; }", _.messages.rejectedAfter(), "no space before and oneafter");
  tr.notOk("a { color :pink; }", _.messages.rejectedBefore(), "one space before and non after");
  tr.notOk("a { color\n:pink; }", _.messages.rejectedBefore(), "newline before and no spce after");
  tr.notOk("a { color:\npink; }", _.messages.rejectedAfter(), "no space before and newine after");
});