"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "declaration-colon-space";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected single space before \":\"";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before \":\"";
  },
  expectedAfter: function expectedAfter() {
    return "Expected single space after \":\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after \":\"";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  return function (css, result) {

    if (!options) {
      return;
    }

    var spaceOptions = _utils.standardWhitespaceOptions(options);
    var spaceChecker = _utils.standardWhitespaceChecker(" ", spaceOptions, messages);

    css.eachDecl(function (decl) {

      var declString = decl.toString();

      for (var i = 0, l = declString.length; i < l; i++) {
        if (declString[i] !== ":") {
          continue;
        }
        checkColon(i);
        break;
      }

      function checkColon(index) {
        spaceChecker.before(declString, index, function (msg) {
          result.warn(msg, { node: decl });
        });
        spaceChecker.after(declString, index, function (msg) {
          result.warn(msg, { node: decl });
        });
      }
    });
  };
};