"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.declarationCommaSpaceChecker = declarationCommaSpaceChecker;

var _utils = require("../../utils");

var ruleName = "declaration-comma-space-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected single space after \",\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after \",\"";
  }
});

exports.messages = messages;
/**
 * @param {"always"|"never"} expectation
 */

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)(" ", expectation, messages);
  return declarationCommaSpaceChecker(checker.after);
};

function declarationCommaSpaceChecker(checkLocation) {
  return function (css, result) {
    css.eachDecl(function (decl) {
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: ",", outsideFunctionalNotation: true }, function (match) {
        checkComma(value, match.startIndex, decl);
      });
    });

    function checkComma(source, index, node) {
      checkLocation(source, index, function (m) {
        return (0, _utils.report)({
          message: m,
          node: node,
          result: result,
          ruleName: ruleName
        });
      });
    }
  };
}