"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "declaration-comma-space";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore() {
    return "Expected single space before comma within a declaration value";
  },
  rejectedBefore: function rejectedBefore() {
    return "Unexpected space before comma within a declaration value";
  },
  expectedAfter: function expectedAfter() {
    return "Expected single space after comma within a declaration value";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected space after comma within a declaration value";
  } });

exports.messages = messages;
/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker(" ", spaceOptions, messages);

  return function (css, result) {
    css.eachDecl(function (decl) {
      // Content might contain commas that we do not care about,
      // so ignore it
      if (decl.prop === "content") {
        return;
      }

      var value = decl.value;
      var isInsideFunction = false;
      for (var i = 0, l = value.length; i < l; i++) {
        var char = value[i];
        // If we are inside a function and not ending it, ignore
        if (isInsideFunction && char !== ")") {
          continue;
        }
        // End of a function, so start inspecting any commas
        if (isInsideFunction && char === ")") {
          isInsideFunction = false;
          continue;
        }
        // Beginning of a function, so stop inspecting commas
        if (!isInsideFunction && char === "(") {
          isInsideFunction = true;
          continue;
        }
        if (!isInsideFunction && char === ",") {
          checkComma(i);
        }
      }

      function checkComma(index) {
        spaceChecker.before(value, index, function (msg) {
          result.warn(msg, { node: decl });
        });
        spaceChecker.after(value, index, function (msg) {
          result.warn(msg, { node: decl });
        });
      }
    });
  };
};