"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "property-value-no-vendor-prefix";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  rejected: function rejected(p) {
    return "Unexpected vendor-prefixed property value \"" + p + "\"";
  }
});

exports.messages = messages;
var valuePrefixes = ["-webkit-", "-moz-", "-ms-", "-o-"];

exports["default"] = function () {
  return function (css, result) {
    css.eachDecl(function (decl) {
      var prop = decl.prop;
      var value = decl.value;

      (0, _utils.styleSearch)({ source: value, target: valuePrefixes }, function (match) {
        var fullIdentifier = /^(-[a-z-]+)\b/.exec(value.slice(match.startIndex))[1];
        if (_utils.isAutoprefixable.propertyValue(prop, fullIdentifier)) {
          (0, _utils.report)({
            message: messages.rejected(fullIdentifier),
            node: decl,
            result: result,
            ruleName: ruleName
          });
        }
      });
    });
  };
};