"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "rule-semicolon-newline-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected newline after \";\"";
  },
  rejectedAfter: function rejectedAfter() {
    return "Unexpected newline after \";\"";
  },
  expectedAfterMultiLine: function expectedAfterMultiLine() {
    return "Expected newline after \";\" within multi-line rule";
  },
  rejectedAfterMultiLine: function rejectedAfterMultiLine() {
    return "Unexpected newline after \";\" within multi-line rule";
  }
});

exports.messages = messages;
/**
 * @param {"always"|"never"|"always-multi-line"|"never-multi-line"} expectation
 */

exports["default"] = function (expectation) {
  var check = (0, _utils.whitespaceChecker)("\n", expectation, messages);
  return function (css, result) {
    css.eachDecl(function (decl) {
      // Ignore last declaration if there's no trailing semicolon
      var parentRule = decl.parent;
      if (!parentRule.semicolon && parentRule.last === decl) {
        return;
      }

      var nextNode = decl.next();
      if (!nextNode) {
        return;
      }

      // Allow end-of-line comments one space after the semicolon
      var nodeToCheck = nextNode.type === "comment" && nextNode.before === " " ? nextNode.next() : nextNode;
      if (!nodeToCheck) {
        return;
      }

      check.afterOneOnly(nodeToCheck.toString(), -1, function (m) {
        return (0, _utils.report)({
          message: m,
          node: decl,
          result: result,
          ruleName: ruleName
        });
      }, parentRule.toString().slice("{"));
    });
  };
};