"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "rule-set-non-nested-empty-line-before";

exports.ruleName = ruleName;
var messages = _utils.ruleMessages(ruleName, {
  expected: "Expected empty line before non-nested rule set",
  rejected: "Unexpected empty line before non-nested rule set" });

exports.messages = messages;
/**
 * @param {"always"|"never"|"always-multi-line"|"never-multi-line"} expectation
 */

exports["default"] = function (expectation) {
  return function (root, result) {
    root.eachRule(function (rule) {

      // Ignore the first node
      if (rule === root.first) {
        return;
      }

      // Ignore nested rule sets
      if (rule.parent !== root) {
        return;
      }

      var expectEmptyLine = expectation === "always" || expectation === "always-multi-line" && !_utils.isSingleLineString(rule.toString());

      var rejectEmptyLine = expectation === "never" || expectation === "never-multi-line" && !_utils.isSingleLineString(rule.toString());

      var emptyLineBefore = rule.before.indexOf("\n\n") !== -1;
      if (expectEmptyLine && !emptyLineBefore) {
        result.warn(messages.expected, { node: rule });
      }
      if (rejectEmptyLine && emptyLineBefore) {
        result.warn(messages.rejected, { node: rule });
      }
    });
  };
};