"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "selector-combinator-space";

exports.ruleName = ruleName;
var messages = _utils.standardWhitespaceMessages(ruleName, {
  expectedBefore: function expectedBefore(c) {
    return "Expected single space before combinator \"" + c + "\"";
  },
  rejectedBefore: function rejectedBefore(c) {
    return "Unexpected space before combinator \"" + c + "\"";
  },
  expectedAfter: function expectedAfter(c) {
    return "Expected single space after combinator \"" + c + "\"";
  },
  rejectedAfter: function rejectedAfter(c) {
    return "Unexpected space after combinator \"" + c + "\"";
  } });

exports.messages = messages;
var combinators = [">", "+", "~"];

/**
 * @param {object} options
 * @param {"always"|"never"} [options.before]
 * @param {"always"|"never"} [options.after]
 */

exports["default"] = function (options) {
  var spaceOptions = _utils.standardWhitespaceOptions(options);
  var spaceChecker = _utils.standardWhitespaceChecker(" ", spaceOptions, messages);

  return function (css, result) {
    css.eachRule(function (rule) {
      var selector = rule.selector;
      for (var i = 0, l = selector.length; i < l; i++) {
        if (combinators.indexOf(selector[i]) === -1) {
          continue;
        }
        checkCombinator(i);
      }

      function checkCombinator(index) {
        spaceChecker.before(selector, index, function (msg) {
          result.warn(msg, { node: rule });
        });
        spaceChecker.after(selector, index, function (msg) {
          result.warn(msg, { node: rule });
        });
      }
    });
  };
};