"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _utils = require("../../utils");

var ruleName = "selector-list-comma-newline-after";

exports.ruleName = ruleName;
var messages = (0, _utils.ruleMessages)(ruleName, {
  expectedAfter: function expectedAfter() {
    return "Expected newline after \",\"";
  },
  expectedAfterMultiLine: function expectedAfterMultiLine() {
    return "Expected newline after \",\" in a multi-line list";
  },
  rejectedAfterMultiLine: function rejectedAfterMultiLine() {
    return "Unexpected whitespace after \",\" in a multi-line list";
  }
});

exports.messages = messages;
/**
 * @param {"always"|"always-multi-line"|"never-multi-line"} expectation
 */

exports["default"] = function (expectation) {
  var checker = (0, _utils.whitespaceChecker)("newline", expectation, messages);
  return function (root, result) {
    root.eachRule(function (rule) {
      // Allow for the special case of nested rule sets
      // that should be indented
      var checkLocation = rule.parent === root ? checker.after : checker.afterOneOnly;

      var selector = rule.selector;
      (0, _utils.styleSearch)({ source: selector, target: "," }, function (match) {
        checkLocation({
          source: selector,
          index: match.startIndex,
          err: function err(m) {
            return (0, _utils.report)({
              message: m,
              node: rule,
              result: result,
              ruleName: ruleName
            });
          }
        });
      });
    });
  };
};